@@ -20,7 +20,7 @@ class Connection {
 	 * @param $fetchMode Defaults to associative.  Override for different behaviour
 	 */
 	function Connection($host, $port, $sslmode, $user, $password, $database, $fetchMode = ADODB_FETCH_ASSOC) {
-		$this->conn = &ADONewConnection('postgres7');
+		$this->conn = ADONewConnection('postgres7');
 		$this->conn->setFetchMode($fetchMode);
 
 		// Ignore host if null
@@ -46,18 +46,14 @@ class Connection {
 	 * Gets the name of the correct database driver to use.  As a side effect,
 	 * sets the platform.
 	 * @param (return-by-ref) $description A description of the database and version
-	 * @return The class name of the driver eg. Postgres73
-	 * @return null if version is < 7.0
+	 * @return The class name of the driver eg. Postgres84
+	 * @return null if version is < 7.4
 	 * @return -3 Database-specific failure
 	 */
 	function getDriver(&$description) {
-		// If we're on a recent enough PHP 5, and against PostgreSQL 7.4 or
-		// higher, we don't need to query for the version.  This gives a great
-		// speed up.				
-		if (function_exists('pg_version')) {
-			$v = pg_version($this->conn->_connectionID);
-			if (isset($v['server'])) $version = $v['server'];			
-		}
+
+		$v = pg_version($this->conn->_connectionID);
+		if (isset($v['server'])) $version = $v['server'];
 		
 		// If we didn't manage to get the version without a query, query...
 		if (!isset($version)) {
@@ -67,41 +63,50 @@ class Connection {
 			$field = $adodb->selectField($sql, 'version');
 	
 			// Check the platform, if it's mingw, set it
-			if (eregi(' mingw ', $field))
+			if (preg_match('/ mingw /i', $field))
 				$this->platform = 'MINGW';
 	
 			$params = explode(' ', $field);
 			if (!isset($params[1])) return -3;
 	
-			$version = $params[1]; // eg. 7.3.2
+			$version = $params[1]; // eg. 8.4.4
 		}
 		
 		$description = "PostgreSQL {$version}";
 
 		// Detect version and choose appropriate database driver
-		// If unknown version, then default to latest driver
-		// All 6.x versions default to oldest driver, even though
-		// it won't work with those versions.
-		if ((int)substr($version, 0, 1) < 7)
+        switch (substr($version,0,2)) {
+            case '10': return 'Postgres10';break;
+            case '11': return 'Postgres11';break;
+            case '12': return 'Postgres';break;
+        }    
+
+		switch (substr($version,0,3)) {
+            case '9.6': return 'Postgres96'; break;
+            case '9.5': return 'Postgres95'; break;
+			case '9.4': return 'Postgres94'; break;
+			case '9.3': return 'Postgres93'; break;
+			case '9.2': return 'Postgres92'; break;
+			case '9.1': return 'Postgres91'; break;
+			case '9.0': return 'Postgres90'; break;
+			case '8.4': return 'Postgres84'; break;
+			case '8.3': return 'Postgres83'; break;
+			case '8.2': return 'Postgres82'; break;
+			case '8.1': return 'Postgres81'; break;
+			case '8.0':
+			case '7.5': return 'Postgres80'; break;
+			case '7.4': return 'Postgres74'; break;
+		}
+
+		/* All <7.4 versions are not supported */
+		// if major version is 7 or less and wasn't cought in the
+		// switch/case block, we have an unsupported version.
+		if ((int)substr($version, 0, 1) < 8)
 			return null;
-		elseif (strpos($version, '8.2') === 0)
-			return 'Postgres82';
-		elseif (strpos($version, '8.1') === 0)
-			return 'Postgres81';
-		elseif (strpos($version, '8.0') === 0 || strpos($version, '7.5') === 0)
-			return 'Postgres80';
-		elseif (strpos($version, '7.4') === 0)
-			return 'Postgres74';
-		elseif (strpos($version, '7.3') === 0)
-			return 'Postgres73';
-		elseif (strpos($version, '7.2') === 0)
-			return 'Postgres72';
-		elseif (strpos($version, '7.1') === 0)
-			return 'Postgres71';
-		elseif (strpos($version, '7.0') === 0)
-			return 'Postgres';
-		else
-			return 'Postgres83';
+
+		// If unknown version, then default to latest driver
+		return 'Postgres';
+
 	}
 
 	/** 
@@ -109,10 +114,7 @@ class Connection {
 	 * @return Error string
 	 */
 	function getLastError() {		
-		if (function_exists('pg_errormessage'))
-			return pg_errormessage($this->conn->_connectionID);
-		else
-			return pg_last_error($this->conn->_connectionID);
+		return pg_last_error($this->conn->_connectionID);
 	}
 }
 
