@@ -5,8 +5,7 @@
 	 * tables, reports, arbitrary queries, etc. to avoid code duplication.
 	 * @param $query The SQL SELECT string to execute
 	 * @param $count The same SQL query, but only retrieves the count of the rows (AS total)
-	 * @param $return_url The return URL
-	 * @param $return_desc The return link name
+	 * @param $return The return section
 	 * @param $page The current page
 	 *
 	 * $Id: display.php,v 1.68 2008/04/14 12:44:27 ioguix Exp $
@@ -32,7 +31,7 @@
 		if (is_array($_REQUEST['key']))
            $key = $_REQUEST['key'];
         else
-           $key = unserialize($_REQUEST['key']);
+           $key = unserialize(urldecode($_REQUEST['key']));
 
 		if ($confirm) {
 			$misc->printTrail($_REQUEST['subject']);
@@ -90,8 +89,8 @@
 						if ($_REQUEST['action'] == 'confeditrow' && $rs->fields[$attrs->fields['attname']] === null) {
 							$_REQUEST['nulls'][$attrs->fields['attname']] = 'on';
 						}
-						echo "<input type=\"checkbox\" name=\"nulls[{$attrs->fields['attname']}]\"",
-							isset($_REQUEST['nulls'][$attrs->fields['attname']]) ? ' checked="checked"' : '', " /></td>\n";
+						echo "<label><span><input type=\"checkbox\" name=\"nulls[{$attrs->fields['attname']}]\"",
+							isset($_REQUEST['nulls'][$attrs->fields['attname']]) ? ' checked="checked"' : '', " /></span></label></td>\n";
 						$elements++;
 					}
 					else
@@ -143,17 +142,15 @@
 				echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars($_REQUEST['query']), "\" />\n";
 			if (isset($_REQUEST['count']))
 				echo "<input type=\"hidden\" name=\"count\" value=\"", htmlspecialchars($_REQUEST['count']), "\" />\n";
-			if (isset($_REQUEST['return_url']))
-				echo "<input type=\"hidden\" name=\"return_url\" value=\"", htmlspecialchars($_REQUEST['return_url']), "\" />\n";
-			if (isset($_REQUEST['return_desc']))
-				echo "<input type=\"hidden\" name=\"return_desc\" value=\"", htmlspecialchars($_REQUEST['return_desc']), "\" />\n";
+			if (isset($_REQUEST['return']))
+				echo "<input type=\"hidden\" name=\"return\" value=\"", htmlspecialchars($_REQUEST['return']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"page\" value=\"", htmlspecialchars($_REQUEST['page']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"sortkey\" value=\"", htmlspecialchars($_REQUEST['sortkey']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"sortdir\" value=\"", htmlspecialchars($_REQUEST['sortdir']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"strings\" value=\"", htmlspecialchars($_REQUEST['strings']), "\" />\n";
-			echo "<input type=\"hidden\" name=\"key\" value=\"", htmlspecialchars(serialize($key)), "\" />\n";
+			echo "<input type=\"hidden\" name=\"key\" value=\"", htmlspecialchars(urlencode(serialize($key))), "\" />\n";
 			echo "<p>";
-			if (!$error) echo "<input type=\"submit\" name=\"save\" value=\"{$lang['strsave']}\" />\n";
+			if (!$error) echo "<input type=\"submit\" name=\"save\" accesskey=\"r\" value=\"{$lang['strsave']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
 
 			if($fksprops !== false) {
@@ -171,7 +168,7 @@
 			if (!isset($_POST['nulls'])) $_POST['nulls'] = array();
 			
 			$status = $data->editRow($_POST['table'], $_POST['values'], $_POST['nulls'], 
-				$_POST['format'], $_POST['types'], unserialize($_POST['key']));
+				$_POST['format'], $_POST['types'], $key);
 			if ($status == 0)
 				doBrowse($lang['strrowupdated']);
 			elseif ($status == -2)
@@ -193,11 +190,36 @@
 			$misc->printTrail($_REQUEST['subject']);
 			$misc->printTitle($lang['strdeleterow']);
 
-			echo "<p>{$lang['strconfdeleterow']}</p>\n";
-			
+			$rs = $data->browseRow($_REQUEST['table'], $_REQUEST['key']);
+
 			echo "<form action=\"display.php\" method=\"post\">\n";
-			echo "<input type=\"hidden\" name=\"action\" value=\"delrow\" />\n";
 			echo $misc->form;
+
+			if ($rs->recordCount() == 1) {
+				echo "<p>{$lang['strconfdeleterow']}</p>\n";
+
+				$fkinfo = array();
+				echo "<table><tr>";
+					printTableHeaderCells($rs, false, true);
+				echo "</tr>";
+				echo "<tr class=\"data1\">\n";
+					printTableRowCells($rs, $fkinfo, true);
+				echo "</tr>\n";
+				echo "</table>\n";
+				echo "<br />\n";
+
+				echo "<input type=\"hidden\" name=\"action\" value=\"delrow\" />\n";
+				echo "<input type=\"submit\" name=\"yes\" value=\"{$lang['stryes']}\" />\n";
+				echo "<input type=\"submit\" name=\"no\" value=\"{$lang['strno']}\" />\n";
+			}
+			elseif ($rs->recordCount() != 1) {
+				echo "<p>{$lang['strrownotunique']}</p>\n";
+				echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
+			}
+			else {
+				echo "<p>{$lang['strinvalidparam']}</p>\n";
+				echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
+			}
 			if (isset($_REQUEST['table']))
 				echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 			if (isset($_REQUEST['subject']))
@@ -206,21 +228,17 @@
 				echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars($_REQUEST['query']), "\" />\n";
 			if (isset($_REQUEST['count']))
 				echo "<input type=\"hidden\" name=\"count\" value=\"", htmlspecialchars($_REQUEST['count']), "\" />\n";
-			if (isset($_REQUEST['return_url']))
-				echo "<input type=\"hidden\" name=\"return_url\" value=\"", htmlspecialchars($_REQUEST['return_url']), "\" />\n";
-			if (isset($_REQUEST['return_desc']))
-				echo "<input type=\"hidden\" name=\"return_desc\" value=\"", htmlspecialchars($_REQUEST['return_desc']), "\" />\n";
+			if (isset($_REQUEST['return']))
+				echo "<input type=\"hidden\" name=\"return\" value=\"", htmlspecialchars($_REQUEST['return']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"page\" value=\"", htmlspecialchars($_REQUEST['page']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"sortkey\" value=\"", htmlspecialchars($_REQUEST['sortkey']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"sortdir\" value=\"", htmlspecialchars($_REQUEST['sortdir']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"strings\" value=\"", htmlspecialchars($_REQUEST['strings']), "\" />\n";
-			echo "<input type=\"hidden\" name=\"key\" value=\"", htmlspecialchars(serialize($_REQUEST['key'])), "\" />\n";
-			echo "<input type=\"submit\" name=\"yes\" value=\"{$lang['stryes']}\" />\n";
-			echo "<input type=\"submit\" name=\"no\" value=\"{$lang['strno']}\" />\n";
+			echo "<input type=\"hidden\" name=\"key\" value=\"", htmlspecialchars(urlencode(serialize($_REQUEST['key']))), "\" />\n";
 			echo "</form>\n";
 		}
 		else {
-			$status = $data->deleteRow($_POST['table'], unserialize($_POST['key']));
+			$status = $data->deleteRow($_POST['table'], unserialize(urldecode($_POST['key'])));
 			if ($status == 0)
 				doBrowse($lang['strrowdeleted']);
 			elseif ($status == -2)
@@ -243,16 +261,7 @@
 			$constraints = $data->getConstraintsWithFields($_REQUEST['table']);
 			if ($constraints->recordCount() > 0) {
 
-				/* build the common parts of the url for the FK  */
-				$fk_return_url = "{$misc->href}&amp;subject=table&amp;table=". urlencode($_REQUEST['table']);
-				if (isset($_REQUEST['page'])) $fk_return_url .= "&amp;page=" . urlencode($_REQUEST['page']);
-				if (isset($_REQUEST['query'])) $fk_return_url .= "&amp;query=" . urlencode($_REQUEST['query']);
-				if (isset($_REQUEST['search_path'])) $fk_return_url .= "&amp;search_path=" . urlencode($_REQUEST['search_path']);
-
-				/* yes, we double urlencode fk_return_url so parameters here don't 
-				 * overwrite real one when included in the final url */
-				$fkey_information['common_url'] = $misc->getHREF('schema') .'&amp;subject=table&amp;return_url=display.php?'
-					. urlencode($fk_return_url) .'&amp;return_desc='. urlencode($lang['strback']);
+				$fkey_information['common_url'] = $misc->getHREF('schema') .'&amp;subject=table';
 
 				/* build the FK constraints data structure */
 				while (!$constraints->EOF) {
@@ -283,9 +292,9 @@
 	}
 
 	/* Print table header cells 
-	 * @param $sortLink must be urlencoded already
+	 * @param $args - associative array for sort link parameters
 	 * */
-	function printTableHeaderCells(&$rs, $sortLink, $withOid) {
+	function printTableHeaderCells(&$rs, $args, $withOid) {
 		global $misc, $data, $conf;
 		$j = 0;
 
@@ -297,16 +306,28 @@
 			}
 			$finfo = $rs->fetchField($j);
 
-			if ($sortLink === false) {
+			if ($args === false) {
 				echo "<th class=\"data\">", $misc->printVal($finfo->name), "</th>\n";
 			}
 			else {
-				echo "<th class=\"data\"><a href=\"display.php?{$sortLink}&amp;sortkey=", ($j + 1), "&amp;sortdir=";
+				$args['page'] = $_REQUEST['page'];
+				$args['sortkey'] = $j + 1;
 				// Sort direction opposite to current direction, unless it's currently ''
-				echo ($_REQUEST['sortdir'] == 'asc' && $_REQUEST['sortkey'] == ($j + 1)) ? 'desc' : 'asc';
-				echo "&amp;strings=", urlencode($_REQUEST['strings']), 
-					"&amp;page=" . urlencode($_REQUEST['page']), "\">", 
-					$misc->printVal($finfo->name), "</a></th>\n";
+				$args['sortdir'] = (
+					$_REQUEST['sortdir'] == 'asc'
+					and $_REQUEST['sortkey'] == ($j + 1)
+				) ? 'desc' : 'asc';
+
+				$sortLink = http_build_query($args);
+
+				echo "<th class=\"data\"><a href=\"?{$sortLink}\">"
+					, $misc->printVal($finfo->name);
+				if($_REQUEST['sortkey'] == ($j + 1)) {
+					if($_REQUEST['sortdir'] == 'asc')
+						echo '<img src="'. $misc->icon('RaiseArgument') .'" alt="asc">';
+					else	echo '<img src="'. $misc->icon('LowerArgument') .'" alt="desc">';
+				}
+				echo "</a></th>\n";
 			}
 			$j++;
 		}
@@ -341,9 +362,9 @@
 						/* $fkey_information['common_url'] is already urlencoded */
 						$query_params .= '&amp;'. $fkey_information['common_url'];
 						echo "<div style=\"display:inline-block;\">";
-						echo "<a class=\"fk fk_". htmlentities($conid) ."\" href=\"display.php?{$query_params}\">";
+						echo "<a class=\"fk fk_". htmlentities($conid, ENT_QUOTES, 'UTF-8') ."\" href=\"display.php?{$query_params}\">";
 						echo "<img src=\"".$misc->icon('ForeignKey')."\" style=\"vertical-align:middle;\" alt=\"[fk]\" title=\""
-							. htmlentities($fkey_information['byconstr'][$conid]['consrc'])
+							. htmlentities($fkey_information['byconstr'][$conid]['consrc'], ENT_QUOTES, 'UTF-8')
 							."\" />";
 						echo "</a>";
 						echo "</div>";
@@ -404,7 +425,7 @@
 	 * Displays requested data
 	 */
 	function doBrowse($msg = '') {
-		global $data, $conf, $misc, $lang;
+		global $data, $conf, $misc, $lang, $plugin_manager;
 
 		$save_history = false;
 		// If current page is not set, default to first page
@@ -422,6 +443,7 @@
 		}
 
 		$misc->printTrail(isset($subject) ? $subject : 'database');
+		$misc->printTabs($subject,'browse');
 
 		/* This code is used when browsing FK in pure-xHTML (without js) */
 		if (isset($_REQUEST['fkey'])) {
@@ -438,12 +460,13 @@
 				$_SESSION['sqlquery'] = $_REQUEST['query'];
 				$misc->printTitle($lang['strselect']);
 				$type = 'SELECT';
-			} else {
-				$misc->printTitle($lang['strbrowse']);
+			}
+			else {
 				$type = 'TABLE';
 			}
 		} else {
 			$misc->printTitle($lang['strqueryresults']);
+			/*we comes from sql.php, $_SESSION['sqlquery'] has been set there */
 			$type = 'QUERY';
 		}
 
@@ -474,33 +497,52 @@
 		// Retrieve page from query.  $max_pages is returned by reference.
 		$rs = $data->browseQuery($type, 
 			isset($object) ? $object : null, 
-			isset($_REQUEST['query']) ? $_REQUEST['query'] : null, 
+			isset($_SESSION['sqlquery']) ? $_SESSION['sqlquery'] : null,
 			$_REQUEST['sortkey'], $_REQUEST['sortdir'], $_REQUEST['page'],
 			$conf['max_rows'], $max_pages);
 
 		$fkey_information =& getFKInfo();
 
-		// Build strings for GETs
-		$gets = $misc->href;
-		if (isset($object)) $gets .= "&amp;" . urlencode($subject) . '=' . urlencode($object);
-		if (isset($subject)) $gets .= "&amp;subject=" . urlencode($subject);
-		if (isset($_REQUEST['query'])) $gets .= "&amp;query=" . urlencode($_REQUEST['query']);
-		if (isset($_REQUEST['count'])) $gets .= "&amp;count=" . urlencode($_REQUEST['count']);
-		if (isset($_REQUEST['return_url'])) $gets .= "&amp;return_url=" . urlencode($_REQUEST['return_url']);
-		if (isset($_REQUEST['return_desc'])) $gets .= "&amp;return_desc=" . urlencode($_REQUEST['return_desc']);
-		if (isset($_REQUEST['search_path'])) $gets .= "&amp;search_path=" . urlencode($_REQUEST['search_path']);
-		if (isset($_REQUEST['table'])) $gets .= "&amp;table=" . urlencode($_REQUEST['table']);
-		
-		// This string just contains sort info
-		$getsort = "sortkey=" . urlencode($_REQUEST['sortkey']) .
-			"&amp;sortdir=" . urlencode($_REQUEST['sortdir']);
+		// Build strings for GETs in array
+		$_gets = array(
+			'server' => $_REQUEST['server'],
+			'database' => $_REQUEST['database']
+		);
+
+		if (isset($_REQUEST['schema'])) $_gets['schema'] = $_REQUEST['schema'];
+		if (isset($object)) $_gets[$subject] = $object;
+		if (isset($subject)) $_gets['subject'] = $subject;
+		if (isset($_REQUEST['query'])) $_gets['query'] = $_REQUEST['query'];
+		if (isset($_REQUEST['count'])) $_gets['count'] = $_REQUEST['count'];
+		if (isset($_REQUEST['return'])) $_gets['return'] = $_REQUEST['return'];
+		if (isset($_REQUEST['search_path'])) $_gets['search_path'] = $_REQUEST['search_path'];
+		if (isset($_REQUEST['table'])) $_gets['table'] = $_REQUEST['table'];
+		if (isset($_REQUEST['sortkey'])) $_gets['sortkey'] = $_REQUEST['sortkey'];
+		if (isset($_REQUEST['sortdir'])) $_gets['sortdir'] = $_REQUEST['sortdir'];
+		if (isset($_REQUEST['nohistory'])) $_gets['nohistory'] = $_REQUEST['nohistory'];
+		$_gets['strings'] = $_REQUEST['strings'];
 
 		if ($save_history && is_object($rs) && ($type == 'QUERY')) //{
 			$misc->saveScriptHistory($_REQUEST['query']);
 
+		echo '<form method="POST" action="'.$_SERVER['REQUEST_URI'].'"><textarea width="90%" name="query" rows="5" cols="100" resizable="true">';
+		if (isset($_REQUEST['query'])) {
+			$query = $_REQUEST['query'];
+		} else {
+			$query = "SELECT * FROM {$_REQUEST['schema']}";
+			if ($_REQUEST['subject'] == 'view') {
+				$query = "{$query}.{$_REQUEST['view']};";
+			} else {
+				$query = "{$query}.{$_REQUEST['table']};";
+			}
+		}
+		//$query = isset($_REQUEST['query'])? $_REQUEST['query'] : "select * from {$_REQUEST['schema']}.{$_REQUEST['table']};";
+		echo $query;
+		echo '</textarea><br><input type="submit"/></form>';
+
 		if (is_object($rs) && $rs->recordCount() > 0) {
 			// Show page navigation
-			$misc->printPages($_REQUEST['page'], $max_pages, "display.php?page=%s&amp;{$gets}&amp;{$getsort}&amp;nohistory=t&amp;strings=" . urlencode($_REQUEST['strings']));
+			$misc->printPages($_REQUEST['page'], $max_pages, $_gets);
 
 			echo "<table id=\"data\">\n<tr>";
 
@@ -515,12 +557,60 @@
 					break;
 				}
 			}
+
+			$buttons = array(
+				'edit' => array (
+					'content' => $lang['stredit'],
+					'attr'=> array (
+						'href' => array (
+							'url' => 'display.php',
+							'urlvars' => array_merge(array (
+								'action' => 'confeditrow',
+								'strings' => $_REQUEST['strings'],
+								'page' => $_REQUEST['page'],
+							), $_gets)
+						)
+					)
+				),
+				'delete' => array (
+					'content' => $lang['strdelete'],
+					'attr'=> array (
+						'href' => array (
+							'url' => 'display.php',
+							'urlvars' => array_merge(array (
+								'action' => 'confdelrow',
+								'strings' => $_REQUEST['strings'],
+								'page' => $_REQUEST['page'],
+							), $_gets)
+						)
+					)
+				),
+			);
+			$actions = array(
+				'actionbuttons' => &$buttons,
+				'place' => 'display-browse'
+			);
+			$plugin_manager->do_hook('actionbuttons', $actions);
+
+			foreach (array_keys($actions['actionbuttons']) as $action) {
+				$actions['actionbuttons'][$action]['attr']['href']['urlvars'] = array_merge(
+					$actions['actionbuttons'][$action]['attr']['href']['urlvars'],
+					$_gets
+				);
+			}
+
+			$edit_params = isset($actions['actionbuttons']['edit'])?
+				$actions['actionbuttons']['edit']:array();
+			$delete_params = isset($actions['actionbuttons']['delete'])?
+				$actions['actionbuttons']['delete']:array();
+
 			// Display edit and delete actions if we have a key
-			if (sizeof($key) > 0)
-				echo "<th colspan=\"2\" class=\"data\">{$lang['stractions']}</th>\n";
+			$colspan = count($buttons);
+			if ($colspan > 0 and count($key) > 0)
+				echo "<th colspan=\"{$colspan}\" class=\"data\">{$lang['stractions']}</th>\n";
 
 			/* we show OIDs only if we are in TABLE or SELECT type browsing */
-			printTableHeaderCells($rs, $gets, isset($object));
+			printTableHeaderCells($rs, $_gets, isset($object));
 
 			echo "</tr>\n";
 
@@ -530,26 +620,41 @@
 				$id = (($i % 2) == 0 ? '1' : '2');
 				echo "<tr class=\"data{$id}\">\n";
 				// Display edit and delete links if we have a key
-				if (sizeof($key) > 0) {
-					$key_str = '';
+				if ($colspan > 0 and count($key) > 0) {
+					$keys_array = array();
 					$has_nulls = false;
 					foreach ($key as $v) {
 						if ($rs->fields[$v] === null) {
 							$has_nulls = true;
 							break;
 						}
-						if ($key_str != '') $key_str .= '&amp;';
-						$key_str .= urlencode("key[{$v}]") . '=' . urlencode($rs->fields[$v]);
+						$keys_array["key[{$v}]"] = $rs->fields[$v];
 					}
 					if ($has_nulls) {
-						echo "<td colspan=\"2\">&nbsp;</td>\n";
+						echo "<td colspan=\"{$colspan}\">&nbsp;</td>\n";
 					} else {
-						echo "<td class=\"opbutton{$id}\"><a href=\"display.php?action=confeditrow&amp;strings=", 
-							urlencode($_REQUEST['strings']), "&amp;page=", 
-							urlencode($_REQUEST['page']), "&amp;{$key_str}&amp;{$gets}&amp;{$getsort}\">{$lang['stredit']}</a></td>\n";
-						echo "<td class=\"opbutton{$id}\"><a href=\"display.php?action=confdelrow&amp;strings=", 
-							urlencode($_REQUEST['strings']), "&amp;page=", 
-							urlencode($_REQUEST['page']), "&amp;{$key_str}&amp;{$gets}&amp;{$getsort}\">{$lang['strdelete']}</a></td>\n";
+
+						if (isset($actions['actionbuttons']['edit'])) {
+							$actions['actionbuttons']['edit'] = $edit_params;
+							$actions['actionbuttons']['edit']['attr']['href']['urlvars'] = array_merge(
+								$actions['actionbuttons']['edit']['attr']['href']['urlvars'],
+								$keys_array
+							);
+						}
+
+						if (isset($actions['actionbuttons']['delete'])) {
+							$actions['actionbuttons']['delete'] = $delete_params;
+							$actions['actionbuttons']['delete']['attr']['href']['urlvars'] = array_merge(
+								$actions['actionbuttons']['delete']['attr']['href']['urlvars'],
+								$keys_array
+							);
+						}
+
+						foreach ($actions['actionbuttons'] as $action) {
+							echo "<td class=\"opbutton{$id}\">";
+							$misc->printLink($action);
+							echo "</td>\n";
+						}
 					}
 				}
 
@@ -563,57 +668,151 @@
 
 			echo "<p>", $rs->recordCount(), " {$lang['strrows']}</p>\n";
 			// Show page navigation
-			$misc->printPages($_REQUEST['page'], $max_pages, "display.php?page=%s&amp;{$gets}&amp;{$getsort}&amp;strings=" . urlencode($_REQUEST['strings']));
+			$misc->printPages($_REQUEST['page'], $max_pages, $_gets);
 		}
 		else echo "<p>{$lang['strnodata']}</p>\n";
 
-		// Navigation links	
-		echo "<ul class=\"navlink\">\n";
+		// Navigation links
+		$navlinks = array();
+
+		$fields = array(
+			'server' => $_REQUEST['server'],
+			'database' => $_REQUEST['database'],
+		);
+
+		if (isset($_REQUEST['schema']))
+			$fields['schema'] = $_REQUEST['schema'];
 
 		// Return
-		if (isset($_REQUEST['return_url']) && isset($_REQUEST['return_desc']))
-			echo "\t<li><a href=\"{$_REQUEST['return_url']}\">{$_REQUEST['return_desc']}</a></li>\n";
+		if (isset($_REQUEST['return'])) {
+			$urlvars = $misc->getSubjectParams($_REQUEST['return']);
+
+			$navlinks['back'] = array (
+				'attr'=> array (
+					'href' => array (
+						'url' => $urlvars['url'],
+						'urlvars' => $urlvars['params']
+					)
+				),
+				'content' => $lang['strback']
+			);
+		}
 
 		// Edit SQL link
-		if (isset($_REQUEST['query']))
-			echo "\t<li><a href=\"database.php?{$misc->href}&amp;action=sql&amp;paginate=on&amp;query=",
-				urlencode($_REQUEST['query']), "\">{$lang['streditsql']}</a></li>\n";
+		if ($type == 'QUERY')
+			$navlinks['edit'] = array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'database.php',
+						'urlvars' => array_merge($fields, array (
+							'action' => 'sql',
+							'paginate' => 'on',
+						))
+					)
+				),
+				'content' => $lang['streditsql']
+			);
 
 		// Expand/Collapse
 		if ($_REQUEST['strings'] == 'expanded')
-			echo "\t<li><a href=\"display.php?{$gets}&amp;{$getsort}&amp;strings=collapsed&amp;page=", 
-				urlencode($_REQUEST['page']), "\">{$lang['strcollapse']}</a></li>\n";
+			$navlinks['collapse'] = array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'display.php',
+						'urlvars' => array_merge(
+							$_gets,
+							array (
+								'strings' => 'collapsed',
+								'page' => $_REQUEST['page']
+						))
+					)
+				),
+				'content' => $lang['strcollapse']
+			);
 		else
-			echo "\t<li><a href=\"display.php?{$gets}&amp;{$getsort}&amp;strings=expanded&amp;page=", 
-				urlencode($_REQUEST['page']), "\">{$lang['strexpand']}</a></li>\n";
-
-		// Create report
-		if (isset($_REQUEST['query']) && ($subject !== 'report') && $conf['show_reports'] && isset($rs) && is_object($rs) && $rs->recordCount() > 0)
-			echo "\t<li><a href=\"reports.php?{$misc->href}&amp;action=create&amp;report_sql=",
-				urlencode($_REQUEST['query']), "&amp;paginate=", (isset($_REQUEST['paginate'])? urlencode($_REQUEST['paginate']):'f'), "\">{$lang['strcreatereport']}</a></li>\n";
+			$navlinks['collapse'] = array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'display.php',
+						'urlvars' => array_merge(
+							$_gets,
+							array (
+								'strings' => 'expanded',
+								'page' => $_REQUEST['page']
+						))
+					)
+				),
+				'content' => $lang['strexpand']
+			);
 
 		// Create view and download
 		if (isset($_REQUEST['query']) && isset($rs) && is_object($rs) && $rs->recordCount() > 0) {
+			
+
 			// Report views don't set a schema, so we need to disable create view in that case
-			if (isset($_REQUEST['schema'])) 
-				echo "\t<li><a href=\"views.php?action=create&amp;formDefinition=",
-					urlencode($_REQUEST['query']), "&amp;{$misc->href}\">{$lang['strcreateview']}</a></li>\n";
-			echo "\t<li><a href=\"dataexport.php?query=", urlencode($_REQUEST['query']);
+			if (isset($_REQUEST['schema'])) {
+
+				$navlinks['createview'] = array (
+					'attr'=> array (
+						'href' => array (
+							'url' => 'views.php',
+							'urlvars' => array_merge($fields, array(
+								'action' => 'create',
+								'formDefinition' => $_REQUEST['query']
+							))
+						)
+					),
+					'content' => $lang['strcreateview']
+				);
+			}
+
+			$urlvars = array();
 			if (isset($_REQUEST['search_path']))
-				echo "&amp;search_path=", urlencode($_REQUEST['search_path']);
-			echo "&amp;{$misc->href}\">{$lang['strdownload']}</a></li>\n";
+				$urlvars['search_path'] = $_REQUEST['search_path'];
+
+			$navlinks['download'] = array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'dataexport.php',
+						'urlvars' => array_merge($fields, $urlvars)
+					)
+				),
+				'content' => $lang['strdownload']
+			);
 		}
 
 		// Insert
 		if (isset($object) && (isset($subject) && $subject == 'table'))
-			echo "\t<li><a href=\"tables.php?action=confinsertrow&amp;table=",
-				urlencode($object), "&amp;{$misc->href}\">{$lang['strinsert']}</a></li>\n";
+			$navlinks['insert'] = array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'tables.php',
+						'urlvars' => array_merge($fields, array(
+							'action' => 'confinsertrow',
+							'table' => $object
+						))
+					)
+				),
+				'content' => $lang['strinsert']
+			);
 
 		// Refresh
-		echo "\t<li><a href=\"display.php?{$gets}&amp;{$getsort}&amp;strings=", urlencode($_REQUEST['strings']), 
-			"&amp;page=" . urlencode($_REQUEST['page']),
-			"\">{$lang['strrefresh']}</a></li>\n";
-		echo "</ul>\n";
+		$navlinks['refresh'] = array (
+			'attr'=> array (
+				'href' => array (
+					'url' => 'display.php',
+					'urlvars' => array_merge(
+						$_gets,
+						array(
+							'strings' => $_REQUEST['strings'],
+							'page' => $_REQUEST['page']
+					))
+				)
+			),
+			'content' => $lang['strrefresh']
+		);
+
+		$misc->printNavLinks($navlinks, 'display-browse', get_defined_vars());
 	}
 
 
@@ -622,8 +821,7 @@
 		doBrowseFK();
 	}
 
-	$scripts  = "<script src=\"libraries/js/jquery.js\" type=\"text/javascript\"></script>\n";
-	$scripts .= "<script src=\"js/display.js\" type=\"text/javascript\"></script>";
+	$scripts = "<script src=\"js/display.js\" type=\"text/javascript\"></script>";
 
 	$scripts .= "<script type=\"text/javascript\">\n";
 	$scripts .= "var Display = {\n";
@@ -631,9 +829,27 @@
 	$scripts .= "};\n";
 	$scripts .= "</script>\n";
 
-	// If a table is specified, then set the title differently
-	if (isset($_REQUEST['subject']) && isset($_REQUEST[$_REQUEST['subject']]))
-		$misc->printHeader($lang['strtables'], $scripts);
+	// Set the title based on the subject of the request 
+	if (isset($_REQUEST['subject']) && isset($_REQUEST[$_REQUEST['subject']])) {
+		if ($_REQUEST['subject'] == 'table') {
+			$misc->printHeader(
+				$lang['strtables'].': '.$_REQUEST[$_REQUEST['subject']],
+				$scripts
+			);
+		}
+		else if ($_REQUEST['subject'] == 'view') {
+			$misc->printHeader(
+				$lang['strviews'].': '.$_REQUEST[$_REQUEST['subject']],
+				$scripts
+			);
+		} 
+        else if ($_REQUEST['subject'] == 'column') {
+            $misc->printHeader(
+                $lang['strcolumn'].': '.$_REQUEST[$_REQUEST['subject']],
+                $scripts
+            );
+        }
+	}
 	else	
 		$misc->printHeader($lang['strqueryresults']);
 
