@@ -9,9 +9,7 @@
 
 	// Language and character set
 	$lang['applang'] = 'English';
-	$lang['appcharset'] = 'ISO-8859-1';
-	$lang['applocale'] = 'en_US';
-	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applocale'] = 'en-US';
 	$lang['applangdir'] = 'ltr';
 
 	// Welcome
@@ -22,7 +20,7 @@
 	$lang['strlocaldocs'] = 'PostgreSQL Documentation (local)';
 	$lang['strreportbug'] = 'Report a Bug';
 	$lang['strviewfaq'] = 'View online FAQ';
-	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
+	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
 	
 	// Basic strings
 	$lang['strlogin'] = 'Login';
@@ -30,6 +28,8 @@
 	$lang['strlogindisallowed'] = 'Login disallowed for security reasons.';
 	$lang['strserver'] = 'Server';
 	$lang['strservers'] = 'Servers';
+	$lang['strgroupservers'] = 'Servers in group "%s"';
+	$lang['strallservers'] = 'All servers';
 	$lang['strintroduction'] = 'Introduction';
 	$lang['strhost'] = 'Host';
 	$lang['strport'] = 'Port';
@@ -60,9 +60,11 @@
 	$lang['stralter'] = 'Alter';
 	$lang['strok'] = 'OK';
 	$lang['strcancel'] = 'Cancel';
+	$lang['strkill'] = 'Kill';
 	$lang['strac'] = 'Enable AutoComplete';
 	$lang['strsave'] = 'Save';
 	$lang['strreset'] = 'Reset';
+	$lang['strrestart'] = 'Restart';
 	$lang['strinsert'] = 'Insert';
 	$lang['strselect'] = 'Select';
 	$lang['strdelete'] = 'Delete';
@@ -124,6 +126,7 @@
 	$lang['strvariables'] = 'Variables';
 	$lang['strprocess'] = 'Process';
 	$lang['strprocesses'] = 'Processes';
+	$lang['strblocked'] = 'Blocked';
 	$lang['strsetting'] = 'Setting';
 	$lang['streditsql'] = 'Edit SQL';
 	$lang['strruntime'] = 'Total runtime: %s ms';
@@ -133,11 +136,25 @@
 	$lang['strfile'] = 'File';
 	$lang['strfileimported'] = 'File imported.';
 	$lang['strtrycred'] = 'Use these credentials for all servers';
+	$lang['strconfdropcred'] = 'For security reason, disconnecting will destroy your shared login information. Are you sure you want to disconnect ?';
 	$lang['stractionsonmultiplelines'] = 'Actions on multiple lines';
 	$lang['strselectall'] = 'Select all';
 	$lang['strunselectall'] = 'Unselect all';
 	$lang['strlocale'] = 'Locale';
-
+	$lang['strcollation'] = 'Collation';
+	$lang['strctype'] = 'Character Type';
+	$lang['strdefaultvalues'] = 'Default values';
+	$lang['strnewvalues'] = 'New values';
+	$lang['strstart'] = 'Start';
+	$lang['strstop'] = 'Stop';
+	$lang['strgotoppage'] = 'back to top';
+	$lang['strtheme'] = 'Theme';
+	$lang['strcluster'] = 'Cluster';
+	
+	// Admin
+	$lang['stradminondatabase'] = 'The following administrative tasks apply on the whole %s database.';
+	$lang['stradminontable'] = 'The following administrative tasks apply on the table %s.';
+	
 	// User-supplied SQL history
 	$lang['strhistory'] = 'History';
 	$lang['strnohistory'] = 'No history.';
@@ -148,6 +165,7 @@
 	$lang['strnodatabaseselected'] = 'Please, select a database.';
 
 	// Database sizes
+	$lang['strnoaccess'] = 'No Access'; 
 	$lang['strsize'] = 'Size';
 	$lang['strbytes'] = 'bytes';
 	$lang['strkb'] = 'kB';
@@ -169,7 +187,6 @@
 	$lang['strnodata'] = 'No rows found.';
 	$lang['strnoobjects'] = 'No objects found.';
 	$lang['strrownotunique'] = 'No unique identifier for this row.';
-	$lang['strnoreportsdb'] = 'You have not created the reports database. Read the INSTALL file for directions.';
 	$lang['strnouploads'] = 'File uploads are disabled.';
 	$lang['strimporterror'] = 'Import error.';
 	$lang['strimporterror-fileformat'] = 'Import error: Failed to automatically determine the file format.';
@@ -179,6 +196,9 @@
 	$lang['strcannotdumponwindows'] = 'Dumping of complex table and schema names on Windows is not supported.';
 	$lang['strinvalidserverparam'] = 'Attempt to connect with invalid server parameter, possibly someone is trying to hack your system.'; 
 	$lang['strnoserversupplied'] = 'No server supplied!';
+	$lang['strbadpgdumppath'] = 'Export error: Failed to execute pg_dump (given path in your conf/config.inc.php : %s). Please, fix this path in your configuration and relog.';
+	$lang['strbadpgdumpallpath'] = 'Export error: Failed to execute pg_dumpall (given path in your conf/config.inc.php : %s). Please, fix this path in your configuration and relog.';
+	$lang['strconnectionfail'] = 'Can not connect to server.';
 
 	// Tables
 	$lang['strtable'] = 'Table';
@@ -208,6 +228,7 @@
 	$lang['strinsertrow'] = 'Insert row';
 	$lang['strrowinserted'] = 'Row inserted.';
 	$lang['strrowinsertedbad'] = 'Row insert failed.';
+	$lang['strnofkref'] = 'There is no matching value in the foreign key %s.';
 	$lang['strrowduplicate'] = 'Row insert failed, attempted to do duplicate insert.';
 	$lang['streditrow'] = 'Edit row';
 	$lang['strrowupdated'] = 'Row updated.';
@@ -240,11 +261,16 @@
 	$lang['strauto'] = 'Auto';
 	$lang['strconfvacuumtable'] = 'Are you sure you want to vacuum "%s"?';
 	$lang['strconfanalyzetable'] = 'Are you sure you want to analyze "%s"?';
+	$lang['strconfreindextable'] = 'Are you sure you want to reindex "%s"?';
+	$lang['strconfclustertable'] = 'Are you sure you want to cluster "%s"?';
 	$lang['strestimatedrowcount'] = 'Estimated row count';
 	$lang['strspecifytabletoanalyze'] = 'You must specify at least one table to analyze.';
 	$lang['strspecifytabletoempty'] = 'You must specify at least one table to empty.';
 	$lang['strspecifytabletodrop'] = 'You must specify at least one table to drop.';
 	$lang['strspecifytabletovacuum'] = 'You must specify at least one table to vacuum.';
+	$lang['strspecifytabletoreindex'] = 'You must specify at least one table to reindex.';
+	$lang['strspecifytabletocluster'] = 'You must specify at least one table to cluster.';
+	$lang['strnofieldsforinsert'] = 'You cannot insert a row into a table with no column.';
 
 	// Columns
 	$lang['strcolprop'] = 'Column properties';
@@ -280,6 +306,7 @@
 	// Groups
 	$lang['strgroup'] = 'Group';
 	$lang['strgroups'] = 'Groups';
+	$lang['strgroupgroups'] = 'Groups in group "%s"';
 	$lang['strshowallgroups'] = 'Show all groups';
 	$lang['strnogroup'] = 'Group not found.';
 	$lang['strnogroups'] = 'No groups found.';
@@ -365,6 +392,11 @@
 	$lang['strdatabasealtered'] = 'Database altered.';
 	$lang['strdatabasealteredbad'] = 'Database alter failed.';
 	$lang['strspecifydatabasetodrop'] = 'You must specify at least one database to drop.';
+	$lang['strtemplatedb'] = 'Template';
+	$lang['strconfanalyzedatabase'] = 'Are you sure you want to analyze all tables in database "%s"?';
+	$lang['strconfvacuumdatabase'] = 'Are you sure you want to vacuum all tables in database "%s"?';
+	$lang['strconfreindexdatabase'] = 'Are you sure you want to reindex all tables in database "%s"?';
+	$lang['strconfclusterdatabase'] = 'Are you sure you want to cluster all tables in database "%s"?';
 
 	// Views
 	$lang['strview'] = 'View';
@@ -404,6 +436,7 @@
 	$lang['strlastvalue'] = 'Last value';
 	$lang['strincrementby'] = 'Increment by';	
 	$lang['strstartvalue'] = 'Start value';
+	$lang['strrestartvalue'] = 'Restart value';
 	$lang['strmaxvalue'] = 'Max value';
 	$lang['strminvalue'] = 'Min value';
 	$lang['strcachevalue'] = 'Cache value';
@@ -416,6 +449,8 @@
 	$lang['strconfdropsequence'] = 'Are you sure you want to drop sequence "%s"?';
 	$lang['strsequencedropped'] = 'Sequence dropped.';
 	$lang['strsequencedroppedbad'] = 'Sequence drop failed.';
+	$lang['strsequencerestart'] = 'Sequence restarted.';
+	$lang['strsequencerestartbad'] = 'Sequence restart failed.';
 	$lang['strsequencereset'] = 'Sequence reset.';
 	$lang['strsequenceresetbad'] = 'Sequence reset failed.';
  	$lang['strsequencealtered'] = 'Sequence altered.';
@@ -451,9 +486,11 @@
  	$lang['strindextype'] = 'Type of index';
 	$lang['strtablecolumnlist'] = 'Columns in table';
 	$lang['strindexcolumnlist'] = 'Columns in index';
-	$lang['strconfcluster'] = 'Are you sure you want to cluster "%s"?';
+	$lang['strconfcluster'] = 'Are you sure you want to cluster on "%s"?';
 	$lang['strclusteredgood'] = 'Cluster complete.';
 	$lang['strclusteredbad'] = 'Cluster failed.';
+	$lang['strconcurrently'] = 'Concurrently';
+	$lang['strnoclusteravailable'] = 'Table not clustered on an index.';
 
 	// Rules
 	$lang['strrules'] = 'Rules';
@@ -624,18 +661,6 @@
 	$lang['strspecifyschematodrop'] = 'You must specify at least one schema to drop.';
 
 	// Reports
-	$lang['strreport'] = 'Report';
-	$lang['strreports'] = 'Reports';
-	$lang['strshowallreports'] = 'Show all reports';
-	$lang['strnoreports'] = 'No reports found.';
-	$lang['strcreatereport'] = 'Create report';
-	$lang['strreportdropped'] = 'Report dropped.';
-	$lang['strreportdroppedbad'] = 'Report drop failed.';
-	$lang['strconfdropreport'] = 'Are you sure you want to drop the report "%s"?';
-	$lang['strreportneedsname'] = 'You must give a name for your report.';
-	$lang['strreportneedsdef'] = 'You must give SQL for your report.';
-	$lang['strreportcreated'] = 'Report saved.';
-	$lang['strreportcreatedbad'] = 'Failed to save report.';
 
 	// Domains
 	$lang['strdomain'] = 'Domain';
@@ -768,120 +793,8 @@
 	$lang['strtablespacealtered'] = 'Tablespace altered.';
 	$lang['strtablespacealteredbad'] = 'Tablespace alteration failed.';
 
-	// Slony clusters
-	$lang['strcluster'] = 'Cluster';
-	$lang['strnoclusters'] = 'No clusters found.';
-	$lang['strconfdropcluster'] = 'Are you sure you want to drop cluster "%s"?';
-	$lang['strclusterdropped'] = 'Cluster dropped.';
-	$lang['strclusterdroppedbad'] = 'Cluster drop failed.';
-	$lang['strinitcluster'] = 'Initialize cluster';
-	$lang['strclustercreated'] = 'Cluster initialized.';
-	$lang['strclustercreatedbad'] = 'Cluster initialization failed.';
-	$lang['strclusterneedsname'] = 'You must give a name for the cluster.';
-	$lang['strclusterneedsnodeid'] = 'You must give an ID for the local node.';
-
-	// Slony nodes
-	$lang['strnodes'] = 'Nodes';
-	$lang['strnonodes'] = 'No nodes found.';
-	$lang['strcreatenode'] = 'Create node';
-	$lang['strid'] = 'ID';
-	$lang['stractive'] = 'Active';
-	$lang['strnodecreated'] = 'Node created.';
-	$lang['strnodecreatedbad'] = 'Node creation failed.';
-	$lang['strconfdropnode'] = 'Are you sure you want to drop node "%s"?';
-	$lang['strnodedropped'] = 'Node dropped.';
-	$lang['strnodedroppedbad'] = 'Node drop failed.';
-	$lang['strfailover'] = 'Failover';
-	$lang['strnodefailedover'] = 'Node failed over.';
-	$lang['strnodefailedoverbad'] = 'Node failover failed.';
-	$lang['strstatus'] = 'Status';	
-	$lang['strhealthy'] = 'Healthy';
-	$lang['stroutofsync'] = 'Out of sync';
-	$lang['strunknown'] = 'Unknown';	
-
-	// Slony paths	
-	$lang['strpaths'] = 'Paths';
-	$lang['strnopaths'] = 'No paths found.';
-	$lang['strcreatepath'] = 'Create path';
-	$lang['strnodename'] = 'Node name';
-	$lang['strnodeid'] = 'Node ID';
-	$lang['strconninfo'] = 'Connection string';
-	$lang['strconnretry'] = 'Seconds before retry to connect';
-	$lang['strpathneedsconninfo'] = 'You must give a connection string for the path.';
-	$lang['strpathneedsconnretry'] = 'You must give the number of seconds to wait before retry to connect.';
-	$lang['strpathcreated'] = 'Path created.';
-	$lang['strpathcreatedbad'] = 'Path creation failed.';
-	$lang['strconfdroppath'] = 'Are you sure you want to drop path "%s"?';
-	$lang['strpathdropped'] = 'Path dropped.';
-	$lang['strpathdroppedbad'] = 'Path drop failed.';
-
-	// Slony listens
-	$lang['strlistens'] = 'Listens';
-	$lang['strnolistens'] = 'No listens found.';
-	$lang['strcreatelisten'] = 'Create listen';
-	$lang['strlistencreated'] = 'Listen created.';
-	$lang['strlistencreatedbad'] = 'Listen creation failed.';
-	$lang['strconfdroplisten'] = 'Are you sure you want to drop listen "%s"?';
-	$lang['strlistendropped'] = 'Listen dropped.';
-	$lang['strlistendroppedbad'] = 'Listen drop failed.';
-
-	// Slony replication sets
-	$lang['strrepsets'] = 'Replication sets';
-	$lang['strnorepsets'] = 'No replication sets found.';
-	$lang['strcreaterepset'] = 'Create replication set';
-	$lang['strrepsetcreated'] = 'Replication set created.';
-	$lang['strrepsetcreatedbad'] = 'Replication set creation failed.';
-	$lang['strconfdroprepset'] = 'Are you sure you want to drop replication set "%s"?';
-	$lang['strrepsetdropped'] = 'Replication set dropped.';
-	$lang['strrepsetdroppedbad'] = 'Replication set drop failed.';
-	$lang['strmerge'] = 'Merge';
-	$lang['strmergeinto'] = 'Merge into';
-	$lang['strrepsetmerged'] = 'Replication sets merged.';
-	$lang['strrepsetmergedbad'] = 'Replication sets merge failed.';
-	$lang['strmove'] = 'Move';
-	$lang['strneworigin'] = 'New origin';
-	$lang['strrepsetmoved'] = 'Replication set moved.';
-	$lang['strrepsetmovedbad'] = 'Replication set move failed.';
-	$lang['strnewrepset'] = 'New replication set';
-	$lang['strlock'] = 'Lock';
-	$lang['strlocked'] = 'Locked';
-	$lang['strunlock'] = 'Unlock';
-	$lang['strconflockrepset'] = 'Are you sure you want to lock replication set "%s"?';
-	$lang['strrepsetlocked'] = 'Replication set locked.';
-	$lang['strrepsetlockedbad'] = 'Replication set lock failed.';
-	$lang['strconfunlockrepset'] = 'Are you sure you want to unlock replication set "%s"?';
-	$lang['strrepsetunlocked'] = 'Replication set unlocked.';
-	$lang['strrepsetunlockedbad'] = 'Replication set unlock failed.';
-	$lang['stronlyonnode'] = 'Only on node';
-	$lang['strddlscript'] = 'DDL script';
-	$lang['strscriptneedsbody'] = 'You must supply a script to be executed on all nodes.';
-	$lang['strscriptexecuted'] = 'Replication set DDL script executed.';
-	$lang['strscriptexecutedbad'] = 'Failed executing replication set DDL script.';
-	$lang['strtabletriggerstoretain'] = 'The following triggers will NOT be disabled by Slony:';
-
-	// Slony tables in replication sets
-	$lang['straddtable'] = 'Add table';
-	$lang['strtableneedsuniquekey'] = 'Table to be added requires a primary or unique key.';
-	$lang['strtableaddedtorepset'] = 'Table added to replication set.';
-	$lang['strtableaddedtorepsetbad'] = 'Failed adding table to replication set.';
-	$lang['strconfremovetablefromrepset'] = 'Are you sure you want to drop the table "%s" from replication set "%s"?';
-	$lang['strtableremovedfromrepset'] = 'Table dropped from replication set.';
-	$lang['strtableremovedfromrepsetbad'] = 'Failed to drop table from replication set.';
-
-	// Slony sequences in replication sets
-	$lang['straddsequence'] = 'Add sequence';
-	$lang['strsequenceaddedtorepset'] = 'Sequence added to replication set.';
-	$lang['strsequenceaddedtorepsetbad'] = 'Failed adding sequence to replication set.';
-	$lang['strconfremovesequencefromrepset'] = 'Are you sure you want to drop the sequence "%s" from replication set "%s"?';
-	$lang['strsequenceremovedfromrepset'] = 'Sequence dropped from replication set.';
-	$lang['strsequenceremovedfromrepsetbad'] = 'Failed to drop sequence from replication set.';
-
-	// Slony subscriptions
-	$lang['strsubscriptions'] = 'Subscriptions';
-	$lang['strnosubscriptions'] = 'No subscriptions found.';
-
 	// Miscellaneous
-	$lang['strtopbar'] = '%s running on %s:%s -- You are logged in as user "%s", %s';
+	$lang['strtopbar'] = '%s running on %s:%s -- You are logged in as user "%s"';
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
 	$lang['strhelp'] = 'Help';
 	$lang['strhelpicon'] = '?';
@@ -899,12 +812,24 @@
 	$lang['strturnedon'] = 'Turned On';
 	$lang['strturnedoff'] = 'Turned Off';
 	$lang['strenabled'] = 'Enabled';
+	$lang['strnovacuumconf'] = 'No autovacuum configuration found.';
 	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold';
 	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';
 	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';
 	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor';
 	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay';
 	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';
+	$lang['strvacuumpertable'] = 'Autovacuum setup per table';
+	$lang['straddvacuumtable'] = 'Add autovacuum setup for a table';
+	$lang['streditvacuumtable'] = 'Edit autovacuum setup for table %s';
+	$lang['strdelvacuumtable'] = 'Delete autovacuum setup for table %s ?';
+	$lang['strvacuumtablereset'] = 'Autovacuum setup for table %s reset to default values';
+	$lang['strdelvacuumtablefail'] = 'Fail to remove the autovacuum setup for table %s';
+	$lang['strsetvacuumtablesaved'] = 'Autovacuum setup for table %s saved.';
+	$lang['strsetvacuumtablefail'] = 'Autovacuum setup for table %s failed.';
+	$lang['strspecifydelvacuumtable'] = 'You must specify the table you want remove the autovacuum parameters from.';
+	$lang['strspecifyeditvacuumtable'] = 'You must specify the table you want to edit the autovacuum parameters from.';
+	$lang['strnotdefaultinred'] = 'Not default values are in red.';
 
 	// Table-level Locks
 	$lang['strlocks'] = 'Locks';
@@ -972,4 +897,9 @@
 	$lang['strftstabdicts'] = 'Dictionaries';
 	$lang['strftstabparsers'] = 'Parsers';
 	$lang['strftscantparsercopy'] = 'Can\'t specify both parser and template during text search configuration creation.';
+
+	//Plugins
+	$lang['strpluginnotfound'] = 'Error: plugin \'%s\' not found. Check if this plugin exists in the plugins/ directory, or if this plugins has a plugin.php file. Plugin\'s names are case sensitive';
+	$lang['stractionnotfound'] = 'Error: action \'%s\' not found in the \'%s\' plugin, or it was not specified as an action.';
+	$lang['strhooknotfound'] = 'Error: hook \'%s\' is not avaliable.';
 ?>
