@@ -20,14 +20,15 @@
 		'danish' => 'Danish',
 		'dutch' => 'Nederlands',
 		'english' => 'English',
-		'french' => 'Fran&ccedil;ais',
+		'french' => 'Français',
 		'galician' => 'Galego',
 		'german' => 'Deutsch',
-        'greek' => '&#917;&#955;&#955;&#951;&#957;&#953;&#954;&#940;',
+		'greek' => '&#917;&#955;&#955;&#951;&#957;&#953;&#954;&#940;',
 		'hebrew' => 'Hebrew',
+		'hungarian' => 'Magyar',
 		'italian' => 'Italiano',
 		'japanese' => '&#26085;&#26412;&#35486;',
-		'hungarian' => 'Magyar',
+		'lithuanian' => 'Lietuvi&#371;',
 		'mongol' => 'Mongolian',
 		'polish' => 'Polski',
 		'portuguese-br' => 'Portugu&ecirc;s-Brasileiro',
@@ -38,7 +39,7 @@
 		'swedish' => 'Svenska',
 		'spanish' => 'Espa&ntilde;ol',
 		'turkish' => 'T&uuml;rk&ccedil;e',
-		'ukrainian' => '&#1059;&#1082;&#1088;&#1072;&#9558;&#1085;&#1089;&#1100;&#1082;&#1072;'
+		'ukrainian' => '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;'
 	);
 	
 	
@@ -64,11 +65,12 @@
 		'fr' => 'french',
 		'gl' => 'galician',
 		'de' => 'german',
-        'el' => 'greek',
+		'el' => 'greek',
 		'he' => 'hebrew',
+		'hu' => 'hungarian',
 		'it' => 'italian',
 		'ja' => 'japanese',
-		'hu' => 'hungarian',
+		'lt' => 'lithuanian',
 		'mn' => 'mongol',
 		'pl' => 'polish',
 		'pt' => 'portuguese-br',
