@@ -78,8 +78,7 @@
 			echo "<input name=\"name\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"",
 				htmlspecialchars($_POST['name'], ENT_QUOTES), "\" /></td></tr>\n";
 
-			$server_info = $misc->getServerInfo();
-			if ($data->isSuperUser($server_info['username'])) {
+			if ($data->isSuperUser()) {
 				echo "<tr><th class=\"data left required\">{$lang['strowner']}</th>\n";
 				echo "<td class=\"data1\"><select name=\"owner\">";
 				while (!$users->EOF) {
@@ -426,7 +425,7 @@
 			'toolTip'=> field('comment')
 		);
 
-		$misc->printTreeXML($columns, $attrs);
+		$misc->printTree($columns, $attrs, 'tblcolumns');
 
 		exit;
 	}
@@ -448,8 +447,9 @@
 			$data->fieldClean($attname);
 			$data->fieldClean($table);
 
-			$actions['browse']['url'] .= 'query=' . urlencode("SELECT \"{$attname}\", count(*) AS \"count\"
-				FROM \"{$table}\" GROUP BY \"{$attname}\" ORDER BY \"{$attname}\"") . '&amp;';
+			$actions['browse']['attr']['href']['urlvars']['query'] = "SELECT \"{$attname}\", count(*) AS \"count\"
+				FROM \"{$table}\" GROUP BY \"{$attname}\" ORDER BY \"{$attname}\"";
+
 			return $actions;
 		}
 
@@ -491,6 +491,7 @@
 			),
 			'keyprop' => array(
 				'title' => $lang['strconstraints'],
+				'class' => 'constraint_cell',
 				'field' => field('attname'),
 				'type'  => 'callback',
 				'params'=> array(
@@ -503,7 +504,7 @@
 			),
 			'comment' => array(
 				'title' => $lang['strcomment'],
-				'field' => field('comment'),
+				'field' => field('comment')
 			),
 		);
 
@@ -522,31 +523,29 @@
 					switch ($c['contype']) {
 						case 'p':
 							$str .= '<a href="constraints.php?'. $misc->href ."&amp;table=". urlencode($c['p_table']) ."&amp;schema=". urlencode($c['p_schema']) ."\"><img src=\"".
-								$misc->icon('PrimaryKey') .'" alt="[pk]" title="'. htmlentities($c['consrc']) .'" /></a>';
+								$misc->icon('PrimaryKey') .'" alt="[pk]" title="'. htmlentities($c['consrc'], ENT_QUOTES, 'UTF-8') .'" /></a>';
 						break;
 						case 'f':
 							$str .= '<a href="tblproperties.php?'. $misc->href ."&amp;table=". urlencode($c['f_table']) ."&amp;schema=". urlencode($c['f_schema']) ."\"><img src=\"".
-								$misc->icon('ForeignKey') .'" alt="[fk]" title="'. htmlentities($c['consrc']) .'" /></a>';
+								$misc->icon('ForeignKey') .'" alt="[fk]" title="'. htmlentities($c['consrc'], ENT_QUOTES, 'UTF-8') .'" /></a>';
 						break;
 						case 'u':
 							$str .= '<a href="constraints.php?'. $misc->href ."&amp;table=". urlencode($c['p_table']) ."&amp;schema=". urlencode($c['p_schema']) ."\"><img src=\"".
-								$misc->icon('UniqueConstraint') .'" alt="[uniq]" title="'. htmlentities($c['consrc']) .'" /></a>';
+								$misc->icon('UniqueConstraint') .'" alt="[uniq]" title="'. htmlentities($c['consrc'], ENT_QUOTES, 'UTF-8') .'" /></a>';
 						break;
 						case 'c':
 							$str .= '<a href="constraints.php?'. $misc->href ."&amp;table=". urlencode($c['p_table']) ."&amp;schema=". urlencode($c['p_schema']) ."\"><img src=\"".
-								$misc->icon('CheckConstraint') .'" alt="[check]" title="'. htmlentities($c['consrc']) .'" /></a>';
+								$misc->icon('CheckConstraint') .'" alt="[check]" title="'. htmlentities($c['consrc'], ENT_QUOTES, 'UTF-8') .'" /></a>';
 					}
 			}
 
 			return $str;
 		}
 
-		$return_url = urlencode("tblproperties.php?{$misc->href}&amp;table=". urlencode($_REQUEST['table']));
-
 		$actions = array(
 			'browse' => array(
 				'title' => $lang['strbrowse'],
-				'url' => "display.php?{$misc->href}&amp;subject=column&amp;return_url={$return_url}&amp;table=".urlencode($_REQUEST['table'])."&amp;return_desc=" . urlencode($lang['strback']) . '&amp;',
+				'url' => "display.php?{$misc->href}&amp;subject=column&amp;return=table&amp;table=".urlencode($_REQUEST['table']).'&amp;',
 				'vars' => array('column' => 'attname'),
 			),
 			'alter' => array(
@@ -566,18 +565,179 @@
 			),
 		);
 
-		$misc->printTable($attrs, $columns, $actions, null, 'attPre');
+		$actions = array(
+			'browse' => array(
+				'content' => $lang['strbrowse'],
+				'attr'=> array (
+					'href' => array (
+						'url' => 'display.php',
+						'urlvars' => array (
+							'table' => $_REQUEST['table'],
+							'subject' => 'column',
+							'return' => 'table',
+							'column' => field('attname')
+						)
+					)
+				)
+			),
+			'alter' => array(
+				'content' => $lang['stralter'],
+				'attr'=> array (
+					'href' => array (
+						'url' => 'colproperties.php',
+						'urlvars' => array (
+							'subject' => 'column',
+							'action' => 'properties',
+							'table' => $_REQUEST['table'],
+							'column' => field('attname')
+						)
+					)
+				)
+			),
+			'privileges' => array(
+				'content' => $lang['strprivileges'],
+				'attr'=> array (
+					'href' => array (
+						'url' => 'privileges.php',
+						'urlvars' => array (
+							'subject' => 'column',
+							'table' => $_REQUEST['table'],
+							'column' => field('attname')
+						)
+					)
+				)
+			),
+			'drop' => array(
+				'content' => $lang['strdrop'],
+				'attr'=> array (
+					'href' => array (
+						'url' => 'tblproperties.php',
+						'urlvars' => array (
+							'subject' => 'column',
+							'action' => 'confirm_drop',
+							'table' => $_REQUEST['table'],
+							'column' => field('attname')
+						)
+					)
+				)
+			),
+		);
+
+		$misc->printTable($attrs, $columns, $actions, 'tblproperties-tblproperties', null, 'attPre');
+
+		$navlinks = array (
+			'browse' => array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'display.php',
+						'urlvars' => array (
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table'],
+							'subject' => 'table',
+							'return' => 'table'
+						)
+					)
+				),
+				'content' => $lang['strbrowse']
+			),
+			'select' => array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'tables.php',
+						'urlvars' => array (
+							'action' => 'confselectrows',
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table']
+						)
+					)
+				),
+				'content' => $lang['strselect']
+			),
+			'insert' => array (
+				'attr'=> array (
+					'href' => array (
+					'url' => 'tables.php',
+						'urlvars' => array (
+							'action' => 'confinsertrow',
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table']
+						)
+					)
+				),
+				'content' => $lang['strinsert']
+			),
+			'empty' => array (
+				'attr'=> array (
+					'href' => array (
+					'url' => 'tables.php',
+						'urlvars' => array (
+							'action' => 'confirm_empty',
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table']
+						)
+					)
+				),
+				'content' => $lang['strempty']
+			),
+			'drop' => array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'tables.php',
+						'urlvars' => array (
+							'action' => 'confirm_drop',
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table'],
+						)
+					)
+				),
+				'content' => $lang['strdrop']
+			),
+			'addcolumn' => array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'tblproperties.php',
+						'urlvars' => array (
+							'action' => 'add_column',
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table']
+						)
+					)
+				),
+				'content' => $lang['straddcolumn']
+			),
+			'alter' => array (
+				'attr'=> array (
+					'href' => array (
+						'url' => 'tblproperties.php',
+						'urlvars' => array (
+							'action' => 'confirm_alter',
+							'server' => $_REQUEST['server'],
+							'database' => $_REQUEST['database'],
+							'schema' => $_REQUEST['schema'],
+							'table' => $_REQUEST['table']
+						)
+					)
+				),
+				'content' => $lang['stralter']
+			)
+		);
+		$misc->printNavLinks($navlinks,
+			'tblproperties-tblproperties'
+			, get_defined_vars()
+		);
 
-		echo "<ul class=\"navlink\">\n";
-		echo "\t<li><a href=\"display.php?{$misc->href}&amp;table=", urlencode($_REQUEST['table']), "&amp;subject=table&amp;return_url={$return_url}&amp;return_desc=",
-			urlencode($lang['strback']), "\">{$lang['strbrowse']}</a></li>\n";
-		echo "\t<li><a href=\"tables.php?action=confselectrows&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strselect']}</a></li>\n";
-		echo "\t<li><a href=\"tables.php?action=confinsertrow&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strinsert']}</a></li>\n";
-		echo "\t<li><a href=\"tables.php?action=confirm_empty&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strempty']}</a></li>\n";
-		echo "\t<li><a href=\"tables.php?action=confirm_drop&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strdrop']}</a></li>\n";
-		echo "\t<li><a href=\"tblproperties.php?action=add_column&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['straddcolumn']}</a></li>\n";
-		echo "\t<li><a href=\"tblproperties.php?action=confirm_alter&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['stralter']}</a></li>\n";
-		echo "</ul>\n";
 	}
 
 	$misc->printHeader($lang['strtables'] . ' - ' . $_REQUEST['table']);
